@@ -1,7 +1,11 @@
 from reconfigure.nodes import *
 from reconfigure.parsers import BaseParser
-from iniparse import INIConfig
-from StringIO import StringIO
+from reconfigure.parsers.iniparse import INIConfig
+
+try:
+    from StringIO import StringIO
+except ImportError:
+    from io import StringIO
 
 
 class IniFileParser (BaseParser):
@@ -39,9 +43,10 @@ class IniFileParser (BaseParser):
             section_node = Node(name)
             section_node.comment = self._get_comment(cp[section]._lines[0])
             for option in cp[section]:
-                node = PropertyNode(option, cp[section][option])
-                node.comment = self._get_comment(cp[section]._options[option])
-                section_node.children.append(node)
+                if option in cp[section]._options:
+                    node = PropertyNode(option, cp[section][option])
+                    node.comment = self._get_comment(cp[section]._options[option])
+                    section_node.children.append(node)
             root.children.append(section_node)
         return root
 
